@@ -163,6 +163,7 @@ def update(product, index_url):
     * rqalpha_plus - 多资产回测引擎
     * rqoptimizer - 股票优化器
     * rqfactor - 因子投研和检验
+    * rqpattr - 绩效归因计算
     """
     if product != "":
         if product not in PRODUCTS:
@@ -185,6 +186,11 @@ def update(product, index_url):
                 key.append('rqoptimizer')
             except ImportError:
                 pass
+            try:
+                import rqpattr
+                key.append('rqpattr')
+            except ImportError:
+                pass
 
     full_name = "rqsdk[{}]".format(",".join(key))
     click.echo("开始更新 {} 请稍后...".format(full_name))
@@ -209,6 +215,7 @@ def install(product, index_url):
     * rqalpha_plus - 多资产回测引擎
     * rqoptimizer - 股票优化器
     * rqfactor - 因子投研和检验
+    * rqpattr - 绩效归因计算
     """
 
     if product == 'rqsdk':
